#
# PySNMP MIB module CISCO-PIM-MIB (http://snmplabs.com/pysmi)
# ASN.1 source file:///home/mvold/d/zino/mibs/CISCO-PIM-MIB.my
# Produced by pysmi-0.3.4 at Thu Jul 18 12:37:03 2024
# On host agrajag platform Linux version 6.6.37 by user mvold
# Using Python version 3.11.9 (main, Apr  2 2024, 08:25:04) [GCC 13.2.0]
#
ObjectIdentifier, OctetString, Integer = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
NamedValues, = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
ConstraintsIntersection, ConstraintsUnion, SingleValueConstraint, ValueSizeConstraint, ValueRangeConstraint = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ConstraintsUnion", "SingleValueConstraint", "ValueSizeConstraint", "ValueRangeConstraint")
ciscoMgmt, = mibBuilder.importSymbols("CISCO-SMI", "ciscoMgmt")
InetAddress, InetAddressType = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
pimInterfaceStatus, pimRPSetHoldTime = mibBuilder.importSymbols("PIM-MIB", "pimInterfaceStatus", "pimRPSetHoldTime")
ModuleCompliance, ObjectGroup, NotificationGroup = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
NotificationType, Counter32, Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Gauge32, IpAddress, Unsigned32, ObjectIdentity, TimeTicks, Counter64, MibIdentifier, ModuleIdentity, Bits = mibBuilder.importSymbols("SNMPv2-SMI", "NotificationType", "Counter32", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Gauge32", "IpAddress", "Unsigned32", "ObjectIdentity", "TimeTicks", "Counter64", "MibIdentifier", "ModuleIdentity", "Bits")
DisplayString, TextualConvention = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
ciscoPimMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 9, 9, 184))
ciscoPimMIB.setRevisions(('2000-11-02 00:00',))
if mibBuilder.loadTexts: ciscoPimMIB.setLastUpdated('200011020000Z')
if mibBuilder.loadTexts: ciscoPimMIB.setOrganization('Cisco Systems, Inc.')
ciscoPimMIBObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 1))
cpim = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1))
cpimInvalidRegisterMsgsRcvd = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimInvalidRegisterMsgsRcvd.setStatus('current')
cpimInvalidJoinPruneMsgsRcvd = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimInvalidJoinPruneMsgsRcvd.setStatus('current')
cpimLastErrorType = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3))).clone(namedValues=NamedValues(("none", 1), ("invalidRegister", 2), ("invalidJoinPrune", 3)))).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimLastErrorType.setStatus('current')
cpimLastErrorOriginType = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 4), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimLastErrorOriginType.setStatus('current')
cpimLastErrorOrigin = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 5), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimLastErrorOrigin.setStatus('current')
cpimLastErrorGroupType = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 6), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimLastErrorGroupType.setStatus('current')
cpimLastErrorGroup = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 7), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimLastErrorGroup.setStatus('current')
cpimLastErrorRPType = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 8), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimLastErrorRPType.setStatus('current')
cpimLastErrorRP = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 1, 1, 9), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimLastErrorRP.setStatus('current')
ciscoPimMIBNotificationPrefix = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 2))
ciscoPimMIBNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 0))
ciscoPimMIBNotificationObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 1))
cpimRPMappingChangeType = MibScalar((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4))).clone(namedValues=NamedValues(("newMapping", 1), ("deletedMapping", 2), ("modifiedOldMapping", 3), ("modifiedNewMapping", 4)))).setMaxAccess("readonly")
if mibBuilder.loadTexts: cpimRPMappingChangeType.setStatus('current')
ciscoPimInterfaceUp = NotificationType((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 0, 1)).setObjects(("PIM-MIB", "pimInterfaceStatus"))
if mibBuilder.loadTexts: ciscoPimInterfaceUp.setStatus('current')
ciscoPimInterfaceDown = NotificationType((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 0, 2)).setObjects(("PIM-MIB", "pimInterfaceStatus"))
if mibBuilder.loadTexts: ciscoPimInterfaceDown.setStatus('current')
ciscoPimRPMappingChange = NotificationType((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 0, 3)).setObjects(("PIM-MIB", "pimRPSetHoldTime"), ("CISCO-PIM-MIB", "cpimRPMappingChangeType"))
if mibBuilder.loadTexts: ciscoPimRPMappingChange.setStatus('current')
ciscoPimInvalidRegister = NotificationType((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 0, 4)).setObjects(("CISCO-PIM-MIB", "cpimLastErrorOriginType"), ("CISCO-PIM-MIB", "cpimLastErrorOrigin"), ("CISCO-PIM-MIB", "cpimLastErrorGroupType"), ("CISCO-PIM-MIB", "cpimLastErrorGroup"), ("CISCO-PIM-MIB", "cpimLastErrorRPType"), ("CISCO-PIM-MIB", "cpimLastErrorRP"), ("CISCO-PIM-MIB", "cpimInvalidRegisterMsgsRcvd"))
if mibBuilder.loadTexts: ciscoPimInvalidRegister.setStatus('current')
ciscoPimInvalidJoinPrune = NotificationType((1, 3, 6, 1, 4, 1, 9, 9, 184, 2, 0, 5)).setObjects(("CISCO-PIM-MIB", "cpimLastErrorOriginType"), ("CISCO-PIM-MIB", "cpimLastErrorOrigin"), ("CISCO-PIM-MIB", "cpimLastErrorGroupType"), ("CISCO-PIM-MIB", "cpimLastErrorGroup"), ("CISCO-PIM-MIB", "cpimLastErrorRPType"), ("CISCO-PIM-MIB", "cpimLastErrorRP"), ("CISCO-PIM-MIB", "cpimInvalidJoinPruneMsgsRcvd"))
if mibBuilder.loadTexts: ciscoPimInvalidJoinPrune.setStatus('current')
ciscoPimMIBConformance = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 3))
ciscoPimMIBCompliances = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 3, 1))
ciscoPimMIBGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 9, 9, 184, 3, 2))
ciscoPimSparseMIBCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 9, 9, 184, 3, 1, 1)).setObjects(("CISCO-PIM-MIB", "ciscoPimSparseMIBGroup"), ("CISCO-PIM-MIB", "ciscoPimNotificationObjectGroup"))

if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    ciscoPimSparseMIBCompliance = ciscoPimSparseMIBCompliance.setStatus('current')
ciscoPimSparseMIBGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 9, 9, 184, 3, 2, 1)).setObjects(("CISCO-PIM-MIB", "cpimInvalidRegisterMsgsRcvd"), ("CISCO-PIM-MIB", "cpimInvalidJoinPruneMsgsRcvd"), ("CISCO-PIM-MIB", "cpimLastErrorType"), ("CISCO-PIM-MIB", "cpimLastErrorOriginType"), ("CISCO-PIM-MIB", "cpimLastErrorOrigin"), ("CISCO-PIM-MIB", "cpimLastErrorGroupType"), ("CISCO-PIM-MIB", "cpimLastErrorGroup"), ("CISCO-PIM-MIB", "cpimLastErrorRPType"), ("CISCO-PIM-MIB", "cpimLastErrorRP"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    ciscoPimSparseMIBGroup = ciscoPimSparseMIBGroup.setStatus('current')
ciscoPimNotificationObjectGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 9, 9, 184, 3, 2, 2)).setObjects(("CISCO-PIM-MIB", "cpimRPMappingChangeType"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    ciscoPimNotificationObjectGroup = ciscoPimNotificationObjectGroup.setStatus('current')
mibBuilder.exportSymbols("CISCO-PIM-MIB", cpimInvalidRegisterMsgsRcvd=cpimInvalidRegisterMsgsRcvd, ciscoPimInterfaceUp=ciscoPimInterfaceUp, cpimLastErrorGroupType=cpimLastErrorGroupType, cpimInvalidJoinPruneMsgsRcvd=cpimInvalidJoinPruneMsgsRcvd, ciscoPimRPMappingChange=ciscoPimRPMappingChange, ciscoPimMIB=ciscoPimMIB, ciscoPimSparseMIBCompliance=ciscoPimSparseMIBCompliance, cpimLastErrorRP=cpimLastErrorRP, cpimLastErrorType=cpimLastErrorType, cpimRPMappingChangeType=cpimRPMappingChangeType, ciscoPimMIBNotificationPrefix=ciscoPimMIBNotificationPrefix, ciscoPimMIBConformance=ciscoPimMIBConformance, cpimLastErrorRPType=cpimLastErrorRPType, ciscoPimMIBCompliances=ciscoPimMIBCompliances, ciscoPimMIBObjects=ciscoPimMIBObjects, cpimLastErrorGroup=cpimLastErrorGroup, cpim=cpim, ciscoPimInvalidJoinPrune=ciscoPimInvalidJoinPrune, ciscoPimMIBNotifications=ciscoPimMIBNotifications, ciscoPimInvalidRegister=ciscoPimInvalidRegister, PYSNMP_MODULE_ID=ciscoPimMIB, ciscoPimMIBGroups=ciscoPimMIBGroups, ciscoPimInterfaceDown=ciscoPimInterfaceDown, cpimLastErrorOriginType=cpimLastErrorOriginType, ciscoPimSparseMIBGroup=ciscoPimSparseMIBGroup, cpimLastErrorOrigin=cpimLastErrorOrigin, ciscoPimNotificationObjectGroup=ciscoPimNotificationObjectGroup, ciscoPimMIBNotificationObjects=ciscoPimMIBNotificationObjects)
