set ::EventIdToIx(100) "auroralane-gw1,30:00:04:AB:05:54:00:01:00:00:00:00:00:00:00:AA,bgp"
global ::EventAttrs_100
set ::EventAttrs_100(bgpAS) "running"
set ::EventAttrs_100(bgpOS) "down"
set ::EventAttrs_100(history) "{1706257668 state change embryonic -> open (monitor)}"
set ::EventAttrs_100(id) "100"
set ::EventAttrs_100(lastevent) "peer is down"
set ::EventAttrs_100(log) "{1706257668 auroralane-gw1 peer 0515:7cfd:1bcc:279e:f5a4:5528:f4c3:58af AS 100 is down (running)}"
set ::EventAttrs_100(opened) "1706257668"
set ::EventAttrs_100(peer-uptime) "420"
set ::EventAttrs_100(polladdr) "219.188.192.78"
set ::EventAttrs_100(priority) "100"
set ::EventAttrs_100(remote-AS) "100"
set ::EventAttrs_100(remote-addr) "0515:7cfd:1bcc:279e:f5a4:5528:f4c3:58af"
set ::EventAttrs_100(router) "auroralane-gw1"
set ::EventAttrs_100(state) "waiting"
set ::EventAttrs_100(type) "bgp"
set ::EventAttrs_100(updated) "1706257668"
set ::EventAttrs_100(invalid_attr) "fake-value"
