#
# PySNMP MIB module JUNIPER-ALARM-MIB (http://snmplabs.com/pysmi)
# ASN.1 source file://./JUNIPER-ALARM-MIB.mib
# Produced by pysmi-1.1.10 at Thu Jul  6 12:36:59 2023
# On host simtve-ThinkPad-X1-Carbon-Gen-9 platform Linux version 5.14.0-1058-oem by user simon
# Using Python version 3.9.16 (main, Dec  7 2022, 01:11:51) 
#
OctetString, ObjectIdentifier, Integer = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
NamedValues, = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion")
jnxMibs, = mibBuilder.importSymbols("JUNIPER-SMI", "jnxMibs")
ModuleCompliance, NotificationGroup = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
Integer32, Unsigned32, Gauge32, ModuleIdentity, Counter64, ObjectIdentity, iso, IpAddress, MibIdentifier, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, TimeTicks, NotificationType = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "Unsigned32", "Gauge32", "ModuleIdentity", "Counter64", "ObjectIdentity", "iso", "IpAddress", "MibIdentifier", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "TimeTicks", "NotificationType")
DisplayString, TextualConvention, TimeStamp = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention", "TimeStamp")
jnxAlarms = ModuleIdentity((1, 3, 6, 1, 4, 1, 2636, 3, 4))
if mibBuilder.loadTexts: jnxAlarms.setLastUpdated('200307182153Z')
if mibBuilder.loadTexts: jnxAlarms.setOrganization('Juniper Networks, Inc.')
jnxCraftAlarms = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2))
jnxAlarmRelayMode = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3))).clone(namedValues=NamedValues(("other", 1), ("passOn", 2), ("cutOff", 3)))).setMaxAccess("readonly")
if mibBuilder.loadTexts: jnxAlarmRelayMode.setStatus('current')
jnxYellowAlarms = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 2))
jnxYellowAlarmState = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 2, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3))).clone(namedValues=NamedValues(("other", 1), ("off", 2), ("on", 3)))).setMaxAccess("readonly")
if mibBuilder.loadTexts: jnxYellowAlarmState.setStatus('current')
jnxYellowAlarmCount = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 2, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: jnxYellowAlarmCount.setStatus('current')
jnxYellowAlarmLastChange = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 2, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: jnxYellowAlarmLastChange.setStatus('current')
jnxRedAlarms = MibIdentifier((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 3))
jnxRedAlarmState = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 3, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3))).clone(namedValues=NamedValues(("other", 1), ("off", 2), ("on", 3)))).setMaxAccess("readonly")
if mibBuilder.loadTexts: jnxRedAlarmState.setStatus('current')
jnxRedAlarmCount = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 3, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: jnxRedAlarmCount.setStatus('current')
jnxRedAlarmLastChange = MibScalar((1, 3, 6, 1, 4, 1, 2636, 3, 4, 2, 3, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: jnxRedAlarmLastChange.setStatus('current')
mibBuilder.exportSymbols("JUNIPER-ALARM-MIB", jnxYellowAlarmCount=jnxYellowAlarmCount, jnxRedAlarmLastChange=jnxRedAlarmLastChange, PYSNMP_MODULE_ID=jnxAlarms, jnxAlarms=jnxAlarms, jnxRedAlarmCount=jnxRedAlarmCount, jnxYellowAlarmState=jnxYellowAlarmState, jnxCraftAlarms=jnxCraftAlarms, jnxRedAlarms=jnxRedAlarms, jnxYellowAlarms=jnxYellowAlarms, jnxAlarmRelayMode=jnxAlarmRelayMode, jnxRedAlarmState=jnxRedAlarmState, jnxYellowAlarmLastChange=jnxYellowAlarmLastChange)
